==> vtk-6.3.0-5-armv7h.pkg.tar.xz: vtk/vtkImageAnisotropicDiffusion3D.java <==
// java wrapper for vtkImageAnisotropicDiffusion3D object
//

package vtk;
import vtk.*;

public class vtkImageAnisotropicDiffusion3D extends vtkImageSpatialAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetNumberOfIterations_2(int id0);
  public void SetNumberOfIterations(int id0)
    { SetNumberOfIterations_2(id0); }

  private native int GetNumberOfIterations_3();
  public int GetNumberOfIterations()
    { return GetNumberOfIterations_3(); }

  private native void SetDiffusionThreshold_4(double id0);
  public void SetDiffusionThreshold(double id0)
    { SetDiffusionThreshold_4(id0); }

  private native double GetDiffusionThreshold_5();
  public double GetDiffusionThreshold()
    { return GetDiffusionThreshold_5(); }

  private native void SetDiffusionFactor_6(double id0);
  public void SetDiffusionFactor(double id0)
    { SetDiffusionFactor_6(id0); }

  private native double GetDiffusionFactor_7();
  public double GetDiffusionFactor()
    { return GetDiffusionFactor_7(); }

  private native void SetFaces_8(int id0);
  public void SetFaces(int id0)
    { SetFaces_8(id0); }

  private native int GetFaces_9();
  public int GetFaces()
    { return GetFaces_9(); }

  private native void FacesOn_10();
  public void FacesOn()
    { FacesOn_10(); }

  private native void FacesOff_11();
  public void FacesOff()
    { FacesOff_11(); }

  private native void SetEdges_12(int id0);
  public void SetEdges(int id0)
    { SetEdges_12(id0); }

  private native int GetEdges_13();
  public int GetEdges()
    { return GetEdges_13(); }

  private native void EdgesOn_14();
  public void EdgesOn()
    { EdgesOn_14(); }

  private native void EdgesOff_15();
  public void EdgesOff()
    { EdgesOff_15(); }

  private native void SetCorners_16(int id0);
  public void SetCorners(int id0)
    { SetCorners_16(id0); }

  private native int GetCorners_17();
  public int GetCorners()
    { return GetCorners_17(); }

  private native void CornersOn_18();
  public void CornersOn()
    { CornersOn_18(); }

  private native void CornersOff_19();
  public void CornersOff()
    { CornersOff_19(); }

  private native void SetGradientMagnitudeThreshold_20(int id0);
  public void SetGradientMagnitudeThreshold(int id0)
    { SetGradientMagnitudeThreshold_20(id0); }

  private native int GetGradientMagnitudeThreshold_21();
  public int GetGradientMagnitudeThreshold()
    { return GetGradientMagnitudeThreshold_21(); }

  private native void GradientMagnitudeThresholdOn_22();
  public void GradientMagnitudeThresholdOn()
    { GradientMagnitudeThresholdOn_22(); }

  private native void GradientMagnitudeThresholdOff_23();
  public void GradientMagnitudeThresholdOff()
    { GradientMagnitudeThresholdOff_23(); }

  public vtkImageAnisotropicDiffusion3D() { super(); }

  public vtkImageAnisotropicDiffusion3D(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.2-2-armv7h.pkg.tar.xz: vtk/vtkImageAnisotropicDiffusion3D.java <==
// java wrapper for vtkImageAnisotropicDiffusion3D object
//

package vtk;
import vtk.*;

public class vtkImageAnisotropicDiffusion3D extends vtkImageSpatialAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetNumberOfIterations_2(int id0);
  public void SetNumberOfIterations(int id0)
    { SetNumberOfIterations_2(id0); }

  private native int GetNumberOfIterations_3();
  public int GetNumberOfIterations()
    { return GetNumberOfIterations_3(); }

  private native void SetDiffusionThreshold_4(double id0);
  public void SetDiffusionThreshold(double id0)
    { SetDiffusionThreshold_4(id0); }

  private native double GetDiffusionThreshold_5();
  public double GetDiffusionThreshold()
    { return GetDiffusionThreshold_5(); }

  private native void SetDiffusionFactor_6(double id0);
  public void SetDiffusionFactor(double id0)
    { SetDiffusionFactor_6(id0); }

  private native double GetDiffusionFactor_7();
  public double GetDiffusionFactor()
    { return GetDiffusionFactor_7(); }

  private native void SetFaces_8(int id0);
  public void SetFaces(int id0)
    { SetFaces_8(id0); }

  private native int GetFaces_9();
  public int GetFaces()
    { return GetFaces_9(); }

  private native void FacesOn_10();
  public void FacesOn()
    { FacesOn_10(); }

  private native void FacesOff_11();
  public void FacesOff()
    { FacesOff_11(); }

  private native void SetEdges_12(int id0);
  public void SetEdges(int id0)
    { SetEdges_12(id0); }

  private native int GetEdges_13();
  public int GetEdges()
    { return GetEdges_13(); }

  private native void EdgesOn_14();
  public void EdgesOn()
    { EdgesOn_14(); }

  private native void EdgesOff_15();
  public void EdgesOff()
    { EdgesOff_15(); }

  private native void SetCorners_16(int id0);
  public void SetCorners(int id0)
    { SetCorners_16(id0); }

  private native int GetCorners_17();
  public int GetCorners()
    { return GetCorners_17(); }

  private native void CornersOn_18();
  public void CornersOn()
    { CornersOn_18(); }

  private native void CornersOff_19();
  public void CornersOff()
    { CornersOff_19(); }

  private native void SetGradientMagnitudeThreshold_20(int id0);
  public void SetGradientMagnitudeThreshold(int id0)
    { SetGradientMagnitudeThreshold_20(id0); }

  private native int GetGradientMagnitudeThreshold_21();
  public int GetGradientMagnitudeThreshold()
    { return GetGradientMagnitudeThreshold_21(); }

  private native void GradientMagnitudeThresholdOn_22();
  public void GradientMagnitudeThresholdOn()
    { GradientMagnitudeThresholdOn_22(); }

  private native void GradientMagnitudeThresholdOff_23();
  public void GradientMagnitudeThresholdOff()
    { GradientMagnitudeThresholdOff_23(); }

  public vtkImageAnisotropicDiffusion3D() { super(); }

  public vtkImageAnisotropicDiffusion3D(long id) { super(id); }
  public native long   VTKInit();

}
